@@ -1,14 +1,11 @@
 package Net::CapsuleCRM;
-{
-  $Net::CapsuleCRM::VERSION = '1.123130';
-}
-
+$Net::CapsuleCRM::VERSION = '1.151910';
 use strict;
 use warnings;
 use Moo;
 use Sub::Quote;
 use Method::Signatures;
-use JSON::XS;
+use Cpanel::JSON::XS;
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use XML::Simple;
@@ -141,15 +138,18 @@ method add_tag($id, @tags) {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::CapsuleCRM - Connect to the Capsule API (www.capsulecrm.com)
 
 =head1 VERSION
 
-version 1.123130
+version 1.151910
 
 =head1 SYNOPSIS
 
@@ -211,4 +211,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
